Box3D
Safe HaskellNone
LanguageGHC2021

Box3D.MotorJoint

Synopsis

Documentation

create :: WorldId -> MotorJointDef -> IO JointId Source #

Create a motor joint See also b3MotorJointDef for details.

Binds b3CreateMotorJoint.

setLinearVelocity Source #

Arguments

:: JointId 
-> Vec3
velocity
-> IO () 

Set the desired relative linear velocity in meters per second

Binds b3MotorJoint_SetLinearVelocity.

getLinearVelocity :: JointId -> IO Vec3 Source #

Get the desired relative linear velocity in meters per second

Binds b3MotorJoint_GetLinearVelocity.

getLinearVelocityInto Source #

Arguments

:: JointId 
-> Ptr Vec3

Result buffer.

-> IO () 

Like getLinearVelocity, but the result is written into a caller-supplied buffer.

setAngularVelocity Source #

Arguments

:: JointId 
-> Vec3
velocity
-> IO () 

Set the desired relative angular velocity in radians per second

Binds b3MotorJoint_SetAngularVelocity.

getAngularVelocity :: JointId -> IO Vec3 Source #

Get the desired relative angular velocity in radians per second

Binds b3MotorJoint_GetAngularVelocity.

getAngularVelocityInto Source #

Arguments

:: JointId 
-> Ptr Vec3

Result buffer.

-> IO () 

Like getAngularVelocity, but the result is written into a caller-supplied buffer.

setMaxVelocityForce Source #

Arguments

:: JointId 
-> Float
maxForce
-> IO () 

Set the motor joint maximum force, usually in newtons

Binds b3MotorJoint_SetMaxVelocityForce.

getMaxVelocityForce :: JointId -> IO Float Source #

Get the motor joint maximum force, usually in newtons

Binds b3MotorJoint_GetMaxVelocityForce.

setMaxVelocityTorque Source #

Arguments

:: JointId 
-> Float
maxTorque
-> IO () 

Set the motor joint maximum torque, usually in newton-meters

Binds b3MotorJoint_SetMaxVelocityTorque.

getMaxVelocityTorque :: JointId -> IO Float Source #

Get the motor joint maximum torque, usually in newton-meters

Binds b3MotorJoint_GetMaxVelocityTorque.

setLinearHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the spring linear hertz stiffness

Binds b3MotorJoint_SetLinearHertz.

getLinearHertz :: JointId -> IO Float Source #

Get the spring linear hertz stiffness

Binds b3MotorJoint_GetLinearHertz.

setLinearDampingRatio Source #

Arguments

:: JointId 
-> Float
damping
-> IO () 

Set the spring linear damping ratio. Use 1.0 for critical damping.

Binds b3MotorJoint_SetLinearDampingRatio.

getLinearDampingRatio :: JointId -> IO Float Source #

Get the spring linear damping ratio.

Binds b3MotorJoint_GetLinearDampingRatio.

setAngularHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the spring angular hertz stiffness

Binds b3MotorJoint_SetAngularHertz.

getAngularHertz :: JointId -> IO Float Source #

Get the spring angular hertz stiffness

Binds b3MotorJoint_GetAngularHertz.

setAngularDampingRatio Source #

Arguments

:: JointId 
-> Float
damping
-> IO () 

Set the spring angular damping ratio. Use 1.0 for critical damping.

Binds b3MotorJoint_SetAngularDampingRatio.

getAngularDampingRatio :: JointId -> IO Float Source #

Get the spring angular damping ratio.

Binds b3MotorJoint_GetAngularDampingRatio.

setMaxSpringForce Source #

Arguments

:: JointId 
-> Float
maxForce
-> IO () 

Set the maximum spring force in newtons.

Binds b3MotorJoint_SetMaxSpringForce.

getMaxSpringForce :: JointId -> IO Float Source #

Get the maximum spring force in newtons.

Binds b3MotorJoint_GetMaxSpringForce.

setMaxSpringTorque Source #

Arguments

:: JointId 
-> Float
maxTorque
-> IO () 

Set the maximum spring torque in newtons * meters

Binds b3MotorJoint_SetMaxSpringTorque.

getMaxSpringTorque :: JointId -> IO Float Source #

Get the maximum spring torque in newtons * meters

Binds b3MotorJoint_GetMaxSpringTorque.