| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Box3D.PrismaticJoint
Synopsis
- create :: WorldId -> PrismaticJointDef -> IO JointId
- enableSpring :: JointId -> Bool -> IO ()
- isSpringEnabled :: JointId -> IO Bool
- setSpringHertz :: JointId -> Float -> IO ()
- getSpringHertz :: JointId -> IO Float
- setSpringDampingRatio :: JointId -> Float -> IO ()
- getSpringDampingRatio :: JointId -> IO Float
- setTargetTranslation :: JointId -> Float -> IO ()
- getTargetTranslation :: JointId -> IO Float
- enableLimit :: JointId -> Bool -> IO ()
- isLimitEnabled :: JointId -> IO Bool
- getLowerLimit :: JointId -> IO Float
- getUpperLimit :: JointId -> IO Float
- setLimits :: JointId -> Float -> Float -> IO ()
- enableMotor :: JointId -> Bool -> IO ()
- isMotorEnabled :: JointId -> IO Bool
- setMotorSpeed :: JointId -> Float -> IO ()
- getMotorSpeed :: JointId -> IO Float
- setMaxMotorForce :: JointId -> Float -> IO ()
- getMaxMotorForce :: JointId -> IO Float
- getMotorForce :: JointId -> IO Float
- getTranslation :: JointId -> IO Float
- getSpeed :: JointId -> IO Float
Documentation
create :: WorldId -> PrismaticJointDef -> IO JointId Source #
Create a prismatic (slider) joint. See also b3PrismaticJointDef for details.
Binds b3CreatePrismaticJoint.
Enable/disable the joint spring.
Binds b3PrismaticJoint_EnableSpring.
isSpringEnabled :: JointId -> IO Bool Source #
Is the prismatic joint spring enabled or not?
Binds b3PrismaticJoint_IsSpringEnabled.
Set the prismatic joint stiffness in Hertz. This should usually be less than a quarter of the simulation rate. For example, if the simulation runs at 60Hz then the joint stiffness should be 15Hz or less.
Binds b3PrismaticJoint_SetSpringHertz.
getSpringHertz :: JointId -> IO Float Source #
Get the prismatic joint stiffness in Hertz
Binds b3PrismaticJoint_GetSpringHertz.
setSpringDampingRatio Source #
Set the prismatic joint damping ratio (non-dimensional)
Binds b3PrismaticJoint_SetSpringDampingRatio.
getSpringDampingRatio :: JointId -> IO Float Source #
Get the prismatic spring damping ratio (non-dimensional)
Binds b3PrismaticJoint_GetSpringDampingRatio.
Set the prismatic joint target translation. Usually in meters.
Binds b3PrismaticJoint_SetTargetTranslation.
getTargetTranslation :: JointId -> IO Float Source #
Get the prismatic joint target translation. Usually in meters.
Binds b3PrismaticJoint_GetTargetTranslation.
Enable/disable a prismatic joint limit
Binds b3PrismaticJoint_EnableLimit.
isLimitEnabled :: JointId -> IO Bool Source #
Is the prismatic joint limit enabled?
Binds b3PrismaticJoint_IsLimitEnabled.
getLowerLimit :: JointId -> IO Float Source #
Get the prismatic joint lower limit
Binds b3PrismaticJoint_GetLowerLimit.
getUpperLimit :: JointId -> IO Float Source #
Get the prismatic joint upper limit
Binds b3PrismaticJoint_GetUpperLimit.
Set the prismatic joint limits
Binds b3PrismaticJoint_SetLimits.
Enable/disable a prismatic joint motor
Binds b3PrismaticJoint_EnableMotor.
isMotorEnabled :: JointId -> IO Bool Source #
Is the prismatic joint motor enabled?
Binds b3PrismaticJoint_IsMotorEnabled.
Set the prismatic joint motor speed, usually in meters per second
Binds b3PrismaticJoint_SetMotorSpeed.
getMotorSpeed :: JointId -> IO Float Source #
Get the prismatic joint motor speed, usually in meters per second
Binds b3PrismaticJoint_GetMotorSpeed.
Set the prismatic joint maximum motor force, usually in newtons
Binds b3PrismaticJoint_SetMaxMotorForce.
getMaxMotorForce :: JointId -> IO Float Source #
Get the prismatic joint maximum motor force, usually in newtons
Binds b3PrismaticJoint_GetMaxMotorForce.
getMotorForce :: JointId -> IO Float Source #
Get the prismatic joint current motor force, usually in newtons
Binds b3PrismaticJoint_GetMotorForce.