Box3D
Safe HaskellNone
LanguageGHC2021

Box3D.RevoluteJoint

Synopsis

Documentation

create :: WorldId -> RevoluteJointDef -> IO JointId Source #

Create a revolute joint See also b3RevoluteJointDef for details.

Binds b3CreateRevoluteJoint.

enableSpring Source #

Arguments

:: JointId 
-> Bool
enableSpring
-> IO () 

Enable/disable the revolute joint spring

Binds b3RevoluteJoint_EnableSpring.

isSpringEnabled :: JointId -> IO Bool Source #

Is the revolute angular spring enabled?

Binds b3RevoluteJoint_IsSpringEnabled.

setSpringHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the revolute joint spring stiffness in Hertz

Binds b3RevoluteJoint_SetSpringHertz.

getSpringHertz :: JointId -> IO Float Source #

Get the revolute joint spring stiffness in Hertz

Binds b3RevoluteJoint_GetSpringHertz.

setSpringDampingRatio Source #

Arguments

:: JointId 
-> Float
dampingRatio
-> IO () 

Set the revolute joint spring damping ratio, non-dimensional

Binds b3RevoluteJoint_SetSpringDampingRatio.

getSpringDampingRatio :: JointId -> IO Float Source #

Get the revolute joint spring damping ratio, non-dimensional

Binds b3RevoluteJoint_GetSpringDampingRatio.

setTargetAngle Source #

Arguments

:: JointId 
-> Float
targetRadians
-> IO () 

Set the revolute joint target angle in radians

Binds b3RevoluteJoint_SetTargetAngle.

getTargetAngle :: JointId -> IO Float Source #

Get the revolute joint target angle in radians

Binds b3RevoluteJoint_GetTargetAngle.

getAngle :: JointId -> IO Float Source #

Get the revolute joint current angle in radians relative to the reference angle See also b3RevoluteJointDef::referenceAngle.

Binds b3RevoluteJoint_GetAngle.

enableLimit Source #

Arguments

:: JointId 
-> Bool
enableLimit
-> IO () 

Enable/disable the revolute joint limit

Binds b3RevoluteJoint_EnableLimit.

isLimitEnabled :: JointId -> IO Bool Source #

Is the revolute joint limit enabled?

Binds b3RevoluteJoint_IsLimitEnabled.

getLowerLimit :: JointId -> IO Float Source #

Get the revolute joint lower limit in radians

Binds b3RevoluteJoint_GetLowerLimit.

getUpperLimit :: JointId -> IO Float Source #

Get the revolute joint upper limit in radians

Binds b3RevoluteJoint_GetUpperLimit.

setLimits Source #

Arguments

:: JointId 
-> Float
lowerLimitRadians
-> Float
upperLimitRadians
-> IO () 

Set the revolute joint limits in radians

Binds b3RevoluteJoint_SetLimits.

enableMotor Source #

Arguments

:: JointId 
-> Bool
enableMotor
-> IO () 

Enable/disable a revolute joint motor

Binds b3RevoluteJoint_EnableMotor.

isMotorEnabled :: JointId -> IO Bool Source #

Is the revolute joint motor enabled?

Binds b3RevoluteJoint_IsMotorEnabled.

setMotorSpeed Source #

Arguments

:: JointId 
-> Float
motorSpeed
-> IO () 

Set the revolute joint motor speed in radians per second

Binds b3RevoluteJoint_SetMotorSpeed.

getMotorSpeed :: JointId -> IO Float Source #

Get the revolute joint motor speed in radians per second

Binds b3RevoluteJoint_GetMotorSpeed.

getMotorTorque :: JointId -> IO Float Source #

Get the revolute joint current motor torque, usually in newton-meters

Binds b3RevoluteJoint_GetMotorTorque.

setMaxMotorTorque Source #

Arguments

:: JointId 
-> Float
torque
-> IO () 

Set the revolute joint maximum motor torque, usually in newton-meters

Binds b3RevoluteJoint_SetMaxMotorTorque.

getMaxMotorTorque :: JointId -> IO Float Source #

Get the revolute joint maximum motor torque, usually in newton-meters

Binds b3RevoluteJoint_GetMaxMotorTorque.