Box3D
Safe HaskellNone
LanguageGHC2021

Box3D.WheelJoint

Synopsis

Documentation

create :: WorldId -> WheelJointDef -> IO JointId Source #

Create a wheel joint. See also b3WheelJointDef for details..

Binds b3CreateWheelJoint.

enableSuspension Source #

Arguments

:: JointId 
-> Bool
flag
-> IO () 

Enable/disable the wheel joint spring.

Binds b3WheelJoint_EnableSuspension.

isSuspensionEnabled :: JointId -> IO Bool Source #

Is the wheel joint spring enabled?

Binds b3WheelJoint_IsSuspensionEnabled.

setSuspensionHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the wheel joint stiffness in Hertz.

Binds b3WheelJoint_SetSuspensionHertz.

getSuspensionHertz :: JointId -> IO Float Source #

Get the wheel joint stiffness in Hertz.

Binds b3WheelJoint_GetSuspensionHertz.

setSuspensionDampingRatio Source #

Arguments

:: JointId 
-> Float
dampingRatio
-> IO () 

Set the wheel joint damping ratio, non-dimensional.

Binds b3WheelJoint_SetSuspensionDampingRatio.

getSuspensionDampingRatio :: JointId -> IO Float Source #

Get the wheel joint damping ratio, non-dimensional.

Binds b3WheelJoint_GetSuspensionDampingRatio.

enableSuspensionLimit Source #

Arguments

:: JointId 
-> Bool
flag
-> IO () 

Enable/disable the wheel joint limit.

Binds b3WheelJoint_EnableSuspensionLimit.

isSuspensionLimitEnabled :: JointId -> IO Bool Source #

Is the wheel joint limit enabled?

Binds b3WheelJoint_IsSuspensionLimitEnabled.

getLowerSuspensionLimit :: JointId -> IO Float Source #

Get the wheel joint lower limit.

Binds b3WheelJoint_GetLowerSuspensionLimit.

getUpperSuspensionLimit :: JointId -> IO Float Source #

Get the wheel joint upper limit.

Binds b3WheelJoint_GetUpperSuspensionLimit.

setSuspensionLimits Source #

Arguments

:: JointId 
-> Float
lower
-> Float
upper
-> IO () 

Set the wheel joint limits.

Binds b3WheelJoint_SetSuspensionLimits.

enableSpinMotor Source #

Arguments

:: JointId 
-> Bool
flag
-> IO () 

Enable/disable the wheel joint motor.

Binds b3WheelJoint_EnableSpinMotor.

isSpinMotorEnabled :: JointId -> IO Bool Source #

Is the wheel joint motor enabled?

Binds b3WheelJoint_IsSpinMotorEnabled.

setSpinMotorSpeed Source #

Arguments

:: JointId 
-> Float
speed
-> IO () 

Set the wheel joint motor speed in radians per second.

Binds b3WheelJoint_SetSpinMotorSpeed.

getSpinMotorSpeed :: JointId -> IO Float Source #

Get the wheel joint motor speed in radians per second.

Binds b3WheelJoint_GetSpinMotorSpeed.

setMaxSpinTorque Source #

Arguments

:: JointId 
-> Float
torque
-> IO () 

Set the wheel joint maximum motor torque, usually in newton-meters.

Binds b3WheelJoint_SetMaxSpinTorque.

getMaxSpinTorque :: JointId -> IO Float Source #

Get the wheel joint maximum motor torque, usually in newton-meters.

Binds b3WheelJoint_GetMaxSpinTorque.

getSpinSpeed :: JointId -> IO Float Source #

Get the current spin speed in radians per second.

Binds b3WheelJoint_GetSpinSpeed.

getSpinTorque :: JointId -> IO Float Source #

Get the wheel joint current motor torque, usually in newton-meters.

Binds b3WheelJoint_GetSpinTorque.

enableSteering Source #

Arguments

:: JointId 
-> Bool
flag
-> IO () 

Enable/disable wheel steering. Steering allows the wheel to rotate about the suspension axis.

Binds b3WheelJoint_EnableSteering.

isSteeringEnabled :: JointId -> IO Bool Source #

Can the wheel steer?

Binds b3WheelJoint_IsSteeringEnabled.

setSteeringHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the wheel joint steering stiffness in Hertz.

Binds b3WheelJoint_SetSteeringHertz.

getSteeringHertz :: JointId -> IO Float Source #

Get the wheel joint steering stiffness in Hertz.

Binds b3WheelJoint_GetSteeringHertz.

setSteeringDampingRatio Source #

Arguments

:: JointId 
-> Float
dampingRatio
-> IO () 

Set the wheel joint steering damping ratio, non-dimensional.

Binds b3WheelJoint_SetSteeringDampingRatio.

getSteeringDampingRatio :: JointId -> IO Float Source #

Get the wheel joint steering damping ratio, non-dimensional.

Binds b3WheelJoint_GetSteeringDampingRatio.

setMaxSteeringTorque Source #

Arguments

:: JointId 
-> Float
torque
-> IO () 

Set the wheel joint maximum steering torque in N*m.

Binds b3WheelJoint_SetMaxSteeringTorque.

getMaxSteeringTorque :: JointId -> IO Float Source #

Get the wheel joint maximum steering torque in N*m.

Binds b3WheelJoint_GetMaxSteeringTorque.

enableSteeringLimit Source #

Arguments

:: JointId 
-> Bool
flag
-> IO () 

Enable/disable the wheel joint steering limit.

Binds b3WheelJoint_EnableSteeringLimit.

isSteeringLimitEnabled :: JointId -> IO Bool Source #

Is the wheel joint steering limit enabled?

Binds b3WheelJoint_IsSteeringLimitEnabled.

getLowerSteeringLimit :: JointId -> IO Float Source #

Get the wheel joint lower steering limit in radians.

Binds b3WheelJoint_GetLowerSteeringLimit.

getUpperSteeringLimit :: JointId -> IO Float Source #

Get the wheel joint upper steering limit in radians.

Binds b3WheelJoint_GetUpperSteeringLimit.

setSteeringLimits Source #

Arguments

:: JointId 
-> Float
lowerRadians
-> Float
upperRadians
-> IO () 

Set the wheel joint steering limits in radians.

Binds b3WheelJoint_SetSteeringLimits.

setTargetSteeringAngle Source #

Arguments

:: JointId 
-> Float
radians
-> IO () 

Set the wheel joint target steering angle in radians.

Binds b3WheelJoint_SetTargetSteeringAngle.

getTargetSteeringAngle :: JointId -> IO Float Source #

Get the wheel joint target steering angle in radians.

Binds b3WheelJoint_GetTargetSteeringAngle.

getSteeringAngle :: JointId -> IO Float Source #

Get the current steering angle in radians.

Binds b3WheelJoint_GetSteeringAngle.

getSteeringTorque :: JointId -> IO Float Source #

Get the current steering torque in N*m.

Binds b3WheelJoint_GetSteeringTorque.