| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Box3D.Joint
Synopsis
- destroy :: JointId -> Bool -> IO ()
- isValid :: JointId -> IO Bool
- getType :: JointId -> IO JointType
- getBodyA :: JointId -> IO BodyId
- getBodyB :: JointId -> IO BodyId
- getWorld :: JointId -> IO WorldId
- setLocalFrameA :: JointId -> Transform -> IO ()
- getLocalFrameA :: JointId -> IO Transform
- getLocalFrameAInto :: JointId -> Ptr Transform -> IO ()
- setLocalFrameB :: JointId -> Transform -> IO ()
- getLocalFrameB :: JointId -> IO Transform
- getLocalFrameBInto :: JointId -> Ptr Transform -> IO ()
- setCollideConnected :: JointId -> Bool -> IO ()
- getCollideConnected :: JointId -> IO Bool
- setUserData :: JointId -> Ptr () -> IO ()
- getUserData :: JointId -> IO (Ptr ())
- wakeBodies :: JointId -> IO ()
- getConstraintForce :: JointId -> IO Vec3
- getConstraintForceInto :: JointId -> Ptr Vec3 -> IO ()
- getConstraintTorque :: JointId -> IO Vec3
- getConstraintTorqueInto :: JointId -> Ptr Vec3 -> IO ()
- getLinearSeparation :: JointId -> IO Float
- getAngularSeparation :: JointId -> IO Float
- setConstraintTuning :: JointId -> Float -> Float -> IO ()
- getConstraintTuning :: JointId -> Ptr Float -> Ptr Float -> IO ()
- setForceThreshold :: JointId -> Float -> IO ()
- getForceThreshold :: JointId -> IO Float
- setTorqueThreshold :: JointId -> Float -> IO ()
- getTorqueThreshold :: JointId -> IO Float
Documentation
Destroy a joint
Binds b3DestroyJoint.
isValid :: JointId -> IO Bool Source #
Joint identifier validation. Provides validation for up to 64K allocations.
Binds b3Joint_IsValid.
Set the local frame on bodyA
Binds b3Joint_SetLocalFrameA.
getLocalFrameA :: JointId -> IO Transform Source #
Get the local frame on bodyA
Binds b3Joint_GetLocalFrameA.
Like getLocalFrameA, but the result is written into a caller-supplied buffer.
Set the local frame on bodyB
Binds b3Joint_SetLocalFrameB.
getLocalFrameB :: JointId -> IO Transform Source #
Get the local frame on bodyB
Binds b3Joint_GetLocalFrameB.
Like getLocalFrameB, but the result is written into a caller-supplied buffer.
Toggle collision between connected bodies
Binds b3Joint_SetCollideConnected.
getCollideConnected :: JointId -> IO Bool Source #
Is collision allowed between connected bodies?
Binds b3Joint_GetCollideConnected.
Set the user data on a joint
Binds b3Joint_SetUserData.
getUserData :: JointId -> IO (Ptr ()) Source #
Get the user data on a joint
Binds b3Joint_GetUserData.
wakeBodies :: JointId -> IO () Source #
Wake the bodies connect to this joint
Binds b3Joint_WakeBodies.
getConstraintForce :: JointId -> IO Vec3 Source #
Get the current constraint force for this joint
Binds b3Joint_GetConstraintForce.
getConstraintForceInto Source #
Like getConstraintForce, but the result is written into a caller-supplied buffer.
getConstraintTorque :: JointId -> IO Vec3 Source #
Get the current constraint torque for this joint
Binds b3Joint_GetConstraintTorque.
getConstraintTorqueInto Source #
Like getConstraintTorque, but the result is written into a caller-supplied buffer.
getLinearSeparation :: JointId -> IO Float Source #
Get the current linear separation error for this joint. Does not consider admissible movement. Usually in meters.
Binds b3Joint_GetLinearSeparation.
getAngularSeparation :: JointId -> IO Float Source #
Get the current angular separation error for this joint. Does not consider admissible movement. Usually in radians.
Binds b3Joint_GetAngularSeparation.
Arguments
| :: JointId |
|
| -> Float |
|
| -> Float |
|
| -> IO () |
Set the joint constraint tuning. Advanced feature.
Binds b3Joint_SetConstraintTuning.
Get the joint constraint tuning. Advanced feature.
Binds b3Joint_GetConstraintTuning.
Set the force threshold for joint events (Newtons)
Binds b3Joint_SetForceThreshold.
getForceThreshold :: JointId -> IO Float Source #
Get the force threshold for joint events (Newtons)
Binds b3Joint_GetForceThreshold.
Set the torque threshold for joint events (N-m)
Binds b3Joint_SetTorqueThreshold.