| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Box3D.SphericalJoint
Synopsis
- create :: WorldId -> SphericalJointDef -> IO JointId
- enableConeLimit :: JointId -> Bool -> IO ()
- isConeLimitEnabled :: JointId -> IO Bool
- getConeLimit :: JointId -> IO Float
- setConeLimit :: JointId -> Float -> IO ()
- getConeAngle :: JointId -> IO Float
- enableTwistLimit :: JointId -> Bool -> IO ()
- isTwistLimitEnabled :: JointId -> IO Bool
- getLowerTwistLimit :: JointId -> IO Float
- getUpperTwistLimit :: JointId -> IO Float
- setTwistLimits :: JointId -> Float -> Float -> IO ()
- getTwistAngle :: JointId -> IO Float
- enableSpring :: JointId -> Bool -> IO ()
- isSpringEnabled :: JointId -> IO Bool
- setSpringHertz :: JointId -> Float -> IO ()
- getSpringHertz :: JointId -> IO Float
- setSpringDampingRatio :: JointId -> Float -> IO ()
- getSpringDampingRatio :: JointId -> IO Float
- setTargetRotation :: JointId -> Quat -> IO ()
- getTargetRotation :: JointId -> IO Quat
- getTargetRotationInto :: JointId -> Ptr Quat -> IO ()
- enableMotor :: JointId -> Bool -> IO ()
- isMotorEnabled :: JointId -> IO Bool
- setMotorVelocity :: JointId -> Vec3 -> IO ()
- getMotorVelocity :: JointId -> IO Vec3
- getMotorVelocityInto :: JointId -> Ptr Vec3 -> IO ()
- getMotorTorque :: JointId -> IO Vec3
- getMotorTorqueInto :: JointId -> Ptr Vec3 -> IO ()
- setMaxMotorTorque :: JointId -> Float -> IO ()
- getMaxMotorTorque :: JointId -> IO Float
Documentation
create :: WorldId -> SphericalJointDef -> IO JointId Source #
Create a spherical joint See also b3SphericalJointDef for details.
Binds b3CreateSphericalJoint.
Enable/disable the spherical joint cone limit
Binds b3SphericalJoint_EnableConeLimit.
isConeLimitEnabled :: JointId -> IO Bool Source #
Is the spherical joint cone limit enabled?
Binds b3SphericalJoint_IsConeLimitEnabled.
getConeLimit :: JointId -> IO Float Source #
Get the spherical joint cone limit in radians
Binds b3SphericalJoint_GetConeLimit.
Set the spherical joint limits in radians
Binds b3SphericalJoint_SetConeLimit.
getConeAngle :: JointId -> IO Float Source #
Get the spherical joint current cone angle in radians.
Binds b3SphericalJoint_GetConeAngle.
Enable/disable the spherical joint limit
Binds b3SphericalJoint_EnableTwistLimit.
isTwistLimitEnabled :: JointId -> IO Bool Source #
Is the spherical joint limit enabled?
Binds b3SphericalJoint_IsTwistLimitEnabled.
getLowerTwistLimit :: JointId -> IO Float Source #
Get the spherical joint lower limit in radians
Binds b3SphericalJoint_GetLowerTwistLimit.
getUpperTwistLimit :: JointId -> IO Float Source #
Get the spherical joint upper limit in radians
Binds b3SphericalJoint_GetUpperTwistLimit.
Set the spherical joint limits in radians
Binds b3SphericalJoint_SetTwistLimits.
getTwistAngle :: JointId -> IO Float Source #
Get the spherical joint current twist angle in radians.
Binds b3SphericalJoint_GetTwistAngle.
Enable/disable the spherical joint spring
Binds b3SphericalJoint_EnableSpring.
isSpringEnabled :: JointId -> IO Bool Source #
Is the spherical angular spring enabled?
Binds b3SphericalJoint_IsSpringEnabled.
Set the spherical joint spring stiffness in Hertz
Binds b3SphericalJoint_SetSpringHertz.
getSpringHertz :: JointId -> IO Float Source #
Get the spherical joint spring stiffness in Hertz
Binds b3SphericalJoint_GetSpringHertz.
setSpringDampingRatio Source #
Set the spherical joint spring damping ratio, non-dimensional
Binds b3SphericalJoint_SetSpringDampingRatio.
getSpringDampingRatio :: JointId -> IO Float Source #
Get the spherical joint spring damping ratio, non-dimensional
Binds b3SphericalJoint_GetSpringDampingRatio.
Set the spherical joint spring target rotation
Binds b3SphericalJoint_SetTargetRotation.
getTargetRotation :: JointId -> IO Quat Source #
Get the spherical joint spring target rotation
Binds b3SphericalJoint_GetTargetRotation.
getTargetRotationInto Source #
Like getTargetRotation, but the result is written into a caller-supplied buffer.
Enable/disable a spherical joint motor
Binds b3SphericalJoint_EnableMotor.
isMotorEnabled :: JointId -> IO Bool Source #
Is the spherical joint motor enabled?
Binds b3SphericalJoint_IsMotorEnabled.
Set the spherical joint motor velocity in radians per second
Binds b3SphericalJoint_SetMotorVelocity.
getMotorVelocity :: JointId -> IO Vec3 Source #
Get the spherical joint motor velocity in radians per second
Binds b3SphericalJoint_GetMotorVelocity.
Like getMotorVelocity, but the result is written into a caller-supplied buffer.
getMotorTorque :: JointId -> IO Vec3 Source #
Get the spherical joint current motor torque, usually in newton-meters
Binds b3SphericalJoint_GetMotorTorque.
Like getMotorTorque, but the result is written into a caller-supplied buffer.
Set the spherical joint maximum motor torque, usually in newton-meters
Binds b3SphericalJoint_SetMaxMotorTorque.