| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Box3D.WheelJoint
Synopsis
- create :: WorldId -> WheelJointDef -> IO JointId
- enableSuspension :: JointId -> Bool -> IO ()
- isSuspensionEnabled :: JointId -> IO Bool
- setSuspensionHertz :: JointId -> Float -> IO ()
- getSuspensionHertz :: JointId -> IO Float
- setSuspensionDampingRatio :: JointId -> Float -> IO ()
- getSuspensionDampingRatio :: JointId -> IO Float
- enableSuspensionLimit :: JointId -> Bool -> IO ()
- isSuspensionLimitEnabled :: JointId -> IO Bool
- getLowerSuspensionLimit :: JointId -> IO Float
- getUpperSuspensionLimit :: JointId -> IO Float
- setSuspensionLimits :: JointId -> Float -> Float -> IO ()
- enableSpinMotor :: JointId -> Bool -> IO ()
- isSpinMotorEnabled :: JointId -> IO Bool
- setSpinMotorSpeed :: JointId -> Float -> IO ()
- getSpinMotorSpeed :: JointId -> IO Float
- setMaxSpinTorque :: JointId -> Float -> IO ()
- getMaxSpinTorque :: JointId -> IO Float
- getSpinSpeed :: JointId -> IO Float
- getSpinTorque :: JointId -> IO Float
- enableSteering :: JointId -> Bool -> IO ()
- isSteeringEnabled :: JointId -> IO Bool
- setSteeringHertz :: JointId -> Float -> IO ()
- getSteeringHertz :: JointId -> IO Float
- setSteeringDampingRatio :: JointId -> Float -> IO ()
- getSteeringDampingRatio :: JointId -> IO Float
- setMaxSteeringTorque :: JointId -> Float -> IO ()
- getMaxSteeringTorque :: JointId -> IO Float
- enableSteeringLimit :: JointId -> Bool -> IO ()
- isSteeringLimitEnabled :: JointId -> IO Bool
- getLowerSteeringLimit :: JointId -> IO Float
- getUpperSteeringLimit :: JointId -> IO Float
- setSteeringLimits :: JointId -> Float -> Float -> IO ()
- setTargetSteeringAngle :: JointId -> Float -> IO ()
- getTargetSteeringAngle :: JointId -> IO Float
- getSteeringAngle :: JointId -> IO Float
- getSteeringTorque :: JointId -> IO Float
Documentation
create :: WorldId -> WheelJointDef -> IO JointId Source #
Create a wheel joint. See also b3WheelJointDef for details..
Binds b3CreateWheelJoint.
Enable/disable the wheel joint spring.
Binds b3WheelJoint_EnableSuspension.
isSuspensionEnabled :: JointId -> IO Bool Source #
Is the wheel joint spring enabled?
Binds b3WheelJoint_IsSuspensionEnabled.
Set the wheel joint stiffness in Hertz.
Binds b3WheelJoint_SetSuspensionHertz.
getSuspensionHertz :: JointId -> IO Float Source #
Get the wheel joint stiffness in Hertz.
Binds b3WheelJoint_GetSuspensionHertz.
setSuspensionDampingRatio Source #
Set the wheel joint damping ratio, non-dimensional.
Binds b3WheelJoint_SetSuspensionDampingRatio.
getSuspensionDampingRatio :: JointId -> IO Float Source #
Get the wheel joint damping ratio, non-dimensional.
Binds b3WheelJoint_GetSuspensionDampingRatio.
enableSuspensionLimit Source #
Enable/disable the wheel joint limit.
Binds b3WheelJoint_EnableSuspensionLimit.
isSuspensionLimitEnabled :: JointId -> IO Bool Source #
Is the wheel joint limit enabled?
Binds b3WheelJoint_IsSuspensionLimitEnabled.
getLowerSuspensionLimit :: JointId -> IO Float Source #
Get the wheel joint lower limit.
Binds b3WheelJoint_GetLowerSuspensionLimit.
getUpperSuspensionLimit :: JointId -> IO Float Source #
Get the wheel joint upper limit.
Binds b3WheelJoint_GetUpperSuspensionLimit.
Set the wheel joint limits.
Binds b3WheelJoint_SetSuspensionLimits.
Enable/disable the wheel joint motor.
Binds b3WheelJoint_EnableSpinMotor.
isSpinMotorEnabled :: JointId -> IO Bool Source #
Is the wheel joint motor enabled?
Binds b3WheelJoint_IsSpinMotorEnabled.
Set the wheel joint motor speed in radians per second.
Binds b3WheelJoint_SetSpinMotorSpeed.
getSpinMotorSpeed :: JointId -> IO Float Source #
Get the wheel joint motor speed in radians per second.
Binds b3WheelJoint_GetSpinMotorSpeed.
Set the wheel joint maximum motor torque, usually in newton-meters.
Binds b3WheelJoint_SetMaxSpinTorque.
getMaxSpinTorque :: JointId -> IO Float Source #
Get the wheel joint maximum motor torque, usually in newton-meters.
Binds b3WheelJoint_GetMaxSpinTorque.
getSpinSpeed :: JointId -> IO Float Source #
Get the current spin speed in radians per second.
Binds b3WheelJoint_GetSpinSpeed.
getSpinTorque :: JointId -> IO Float Source #
Get the wheel joint current motor torque, usually in newton-meters.
Binds b3WheelJoint_GetSpinTorque.
Enable/disable wheel steering. Steering allows the wheel to rotate about the suspension axis.
Binds b3WheelJoint_EnableSteering.
isSteeringEnabled :: JointId -> IO Bool Source #
Can the wheel steer?
Binds b3WheelJoint_IsSteeringEnabled.
Set the wheel joint steering stiffness in Hertz.
Binds b3WheelJoint_SetSteeringHertz.
getSteeringHertz :: JointId -> IO Float Source #
Get the wheel joint steering stiffness in Hertz.
Binds b3WheelJoint_GetSteeringHertz.
setSteeringDampingRatio Source #
Set the wheel joint steering damping ratio, non-dimensional.
Binds b3WheelJoint_SetSteeringDampingRatio.
getSteeringDampingRatio :: JointId -> IO Float Source #
Get the wheel joint steering damping ratio, non-dimensional.
Binds b3WheelJoint_GetSteeringDampingRatio.
Set the wheel joint maximum steering torque in N*m.
Binds b3WheelJoint_SetMaxSteeringTorque.
getMaxSteeringTorque :: JointId -> IO Float Source #
Get the wheel joint maximum steering torque in N*m.
Binds b3WheelJoint_GetMaxSteeringTorque.
Enable/disable the wheel joint steering limit.
Binds b3WheelJoint_EnableSteeringLimit.
isSteeringLimitEnabled :: JointId -> IO Bool Source #
Is the wheel joint steering limit enabled?
Binds b3WheelJoint_IsSteeringLimitEnabled.
getLowerSteeringLimit :: JointId -> IO Float Source #
Get the wheel joint lower steering limit in radians.
Binds b3WheelJoint_GetLowerSteeringLimit.
getUpperSteeringLimit :: JointId -> IO Float Source #
Get the wheel joint upper steering limit in radians.
Binds b3WheelJoint_GetUpperSteeringLimit.
Set the wheel joint steering limits in radians.
Binds b3WheelJoint_SetSteeringLimits.
setTargetSteeringAngle Source #
Set the wheel joint target steering angle in radians.
Binds b3WheelJoint_SetTargetSteeringAngle.
getTargetSteeringAngle :: JointId -> IO Float Source #
Get the wheel joint target steering angle in radians.
Binds b3WheelJoint_GetTargetSteeringAngle.